@@ -26,6 +26,7 @@ import operator
 import collections
 import time
 import logging
+import locale
 from optparse import OptionParser, OptionValueError
 
 
@@ -48,6 +49,7 @@ if base_dir not in sys.path:
 
 #from rednotebook.util import filesystem # creates a copy of filesystem module
 #import rednotebook.util.filesystem      # imports the original filesystem module
+from rednotebook.external import elibintl
 
 
 ## ---------------------- Enable i18n -------------------------------
@@ -57,30 +59,6 @@ if base_dir not in sys.path:
 # * gtkbuilder strings
 # * gtk stock names
 
-# set the locale for all categories to the user’s default setting
-# (typically specified in the LANG environment variable)
-import locale
-lang = os.environ.get('LANG', None)
-logging.info('LANG: %s' % lang)
-default_locale = locale.getdefaultlocale()[0]
-logging.info('Default locale: %s' % default_locale)
-try:
-    locale.setlocale(locale.LC_ALL, '')
-    logging.info('Set default locale: "%s"' % default_locale)
-except locale.Error, err:
-    # unsupported locale setting
-    logging.error('Locale "%s" could not be set: "%s"' % (default_locale, err))
-    logging.error('Probably you have to install the appropriate language packs')
-
-# If the default locale could be determined and the LANG env variable
-# has not been set externally, set LANG to the default locale
-# This is necessary only for windows where program strings are not
-# shown in the system language, but in English
-if default_locale and not lang:
-    logging.info('Setting LANG to %s' % default_locale)
-    # sourcecode strings
-    os.environ['LANG'] = default_locale
-
 LOCALE_PATH = os.path.join(filesystem.app_dir, 'i18n')
 
 # the name of the gettext domain. because we have our translation files
@@ -88,32 +66,13 @@ LOCALE_PATH = os.path.join(filesystem.app_dir, 'i18n')
 # application name is a good idea tough.
 GETTEXT_DOMAIN = 'rednotebook'
 
-# set up the gettext system
-import gettext
-
-# Adding locale to the list of modules translates gtkbuilder strings
-modules = [#gettext,
-            locale]
-
-# Sometimes this doesn't work though,
-# so we try to call gtk.glade's function as well if glade is present
+# Register _() as a global translation function and set up the translation
 try:
-    import gtk.glade
-    modules.append(gtk.glade)
-    logging.info('Module glade found')
-except ImportError, err:
-    logging.info('Module glade not found: %s' % err)
-
-for module in modules:
-    try:
-        # locale.bintextdomain and locale textdomain not available on win
-        module.bindtextdomain(GETTEXT_DOMAIN, LOCALE_PATH)
-        module.textdomain(GETTEXT_DOMAIN)
-    except AttributeError, err:
-        logging.info(err)
-
-# register the gettext function for the whole interpreter as "_"
-gettext.install(GETTEXT_DOMAIN, LOCALE_PATH, unicode=1)
+    elibintl.install(GETTEXT_DOMAIN, LOCALE_PATH)
+except locale.Error, err:
+    # unsupported locale setting
+    logging.error('Locale could not be set: "%s"' %  err)
+    logging.error('Probably you have to install the appropriate language packs')
 
 ## ------------------- end Enable i18n -------------------------------
 
