@@ -58,5 +58,7 @@ def format_date(format_string, date=None):
         date_string = _('Incorrect date format')
     # Turn date into unicode string
     locale_name, locale_encoding = locale.getlocale()
+    # locale_encoding may be None may if the value cannot be determined
+    locale_encoding = locale_encoding or 'UTF8'
     date_string = date_string.decode(locale_encoding, 'replace')
     return date_string
